@@ -1,15 +1,13 @@
-from .settings import Settings
-from six import string_types
-from .global_functions import globalFunctions as gf
+from .global_functions import globalFunctions as GF
 import requests
 
+
 class Model:
-    def __init__(self, id="Development"):
-        self._id = id
+    def __init__(self):
         self._model_port = "8000"
         self._modelURL = "127.0.0.1"
 
-    ### Port that is being used by the virtual env ###
+    # Port that is being used by the virtual env #
     @property
     def Model_port(self):
         """
@@ -22,12 +20,9 @@ class Model:
         """
         :type: string
         """
-        if isinstance(value, string_types):
-            self._model_port = value
-        else:
-            raise Exception("Value must be string")
+        self._model_port = GF.Is_value_string(value=value)
 
-    ### URL to model ###
+    # URL to model #
     @property
     def Model_URL(self):
         """
@@ -40,24 +35,47 @@ class Model:
         """
         :type: string
         """
-        if isinstance(value, string_types):
-            self._modelURL = value
-        else:
-            raise Exception("Value must be string")
+        self._modelURL = GF.Is_value_string(value=value)
 
     def Info_request(self):
         response = ""
         try:
-            response = requests.get(url=self._modelURL + ':' + self._model_port + "/info")
-        except:
+            response = requests.get(
+                url=self._modelURL + ':' + self._model_port + "/info")
+        except Exception as e:
+            print(e)
             return Exception("Not able to get data from URL please check if model is running or online")
         return response
 
     def Predict_request(self, json_data=''):
         response = ""
         try:
-            response = requests.post(url=self._modelURL + ':' + self._model_port + "/predict", json=json_data)
-        except:
+            response = requests.post(
+                url=self._modelURL + ':' + self._model_port + "/predict",
+                json=json_data)
+        except Exception as e:
+            print(e)
+            return Exception("Not able to get data from URL please check if model is running or online")
+        return response
+
+    def Validate_request(self, payload):
+        response = ""
+        try:
+            response = requests.put(
+                url=self._modelURL + ':' + self._model_port + "/validate",
+                json=payload)
+        except Exception as e:
+            print(e)
+            return Exception("Not able to get data from URL please check if model is running or online")
+        return response
+
+    def Load_model(self):
+        response = ""
+        try:
+            response = requests.put(
+                url=self._modelURL + ':' + self._model_port + "/loadmodel")
+        except Exception as e:
+            print(e)
             return Exception("Not able to get data from URL please check if model is running or online")
         return response
 
@@ -66,13 +84,19 @@ class Model:
         response = ""
 
         if request_type == "post":
-            response = requests.post(url=self._modelURL + ':' + self._model_port + "/" + pathing, json=json_data)
+            response = requests.post(
+                url=self._modelURL + ':' + self._model_port + "/" + pathing,
+                json=json_data)
             return response
         elif request_type == "put":
-            response = requests.put(url=self._modelURL + ':' + self._model_port + "/" + pathing, json=json_data)
+            response = requests.put(
+                url=self._modelURL + ':' + self._model_port + "/" + pathing,
+                json=json_data)
             return response
         elif request_type == "get":
-            response = requests.get(url=self._modelURL + ':' + self._model_port + "/" + pathing, json=json_data)
+            response = requests.get(
+                url=self._modelURL + ':' + self._model_port + "/" + pathing,
+                json=json_data)
             return response
         else:
             return Exception("Request type not found please the following: get, put, post")
