@@ -1,20 +1,28 @@
 import os
+from .global_functions import globalFunctions as GF
+
 
 class Settings:
     def __init__(self):
-        self._base_path
-        self._premade_main_code_data
-        self._premade_function_code_data
-        self._premade_requirements_data
-        self._premade_documentation_data
-        self._enviroment_name
-        self._package_version
-        self._base_url
-        self._username
-        self._token
-        self._platform_version
+        self._base_path = ""
+        self._premade_main_code_data = ""
+        self._premade_ms_init_code = ""
+        self._premade_function_code_data = ""
+        self._premade_train_code = ""
+        self._premade_requirements_data = ""
+        self._premade_documentation_data = ""
+        self._enviroment_name = ""
+        self._enviroment_version = ""
+        self._package_version = ""
+        self._base_url = ""
+        self._username = ""
+        self._token = ""
+        self._platform_version = ""
+        self._gitaccesstoken = ""
+        self._validation_data_path = ""
+        self._validation_control_data_path = ""
 
-    ### Base path that will be used by the system to work with the system and work from ###
+    # Base path that will be used by the system to work with the system and work from #
     @property
     def Base_path(self):
         """
@@ -29,12 +37,12 @@ class Settings:
         """
         try:
             isDirectory = os.path.isdir(value)
-            if isDirectory == True:
+            if isDirectory is True:
                 self._base_path = value
         except Exception as ex:
             print(ex, "Given path is not a directory")
 
-    ### Premade code that can be used when not using custom code ###
+    # Premade code that can be used when not using custom code #
     @property
     def Premade_main_code_data(self):
         """
@@ -47,24 +55,54 @@ class Settings:
         """
         :type: string
         """
-        self._premade_main_code_data = value
+        self._premade_main_code_data = GF.Is_value_string(value=value)
 
-    ### Premade function code that can be used when not using custom code ###
+    # Premade function code that can be used when not using custom code #
     @property
-    def Premade_function_code_data(self):
+    def Premade_ms_function_code_data(self):
         """
         :type: string
         """
         return self._premade_function_code_data
 
-    @Premade_function_code_data.setter
-    def Premade_function_code_data(self, value):
+    @Premade_ms_function_code_data.setter
+    def Premade_ms_function_code_data(self, value):
         """
         :type: string
         """
-        self._premade_function_code_data = value
+        self._premade_function_code_data = GF.Is_value_string(value=value)
 
-    ### Premade requirements list that can be used when not using custom code ###
+    # Premade function code that can be used when not using custom code #
+    @property
+    def Premade_ms_init_code(self):
+        """
+        :type: string
+        """
+        return self._premade_ms_init_code
+
+    @Premade_ms_init_code.setter
+    def Premade_ms_init_code(self, value):
+        """
+        :type: string
+        """
+        self._premade_ms_init_code = GF.Is_value_string(value=value)
+
+    # Premade train code that can be used when not using custom code #
+    @property
+    def Premade_ms_train_code(self):
+        """
+        :type: string
+        """
+        return self._premade_train_code
+
+    @Premade_ms_train_code.setter
+    def Premade_ms_train_code(self, value):
+        """
+        :type: string
+        """
+        self._premade_train_code = GF.Is_value_string(value=value)
+
+    # Premade requirements list that can be used when not using custom code #
     @property
     def Premade_requirements_data(self):
         """
@@ -77,9 +115,9 @@ class Settings:
         """
         :type: string
         """
-        self._premade_requirements_data = value
+        self._premade_requirements_data = GF.Is_value_string(value=value)
 
-    ### Premade documentation that can be used when not using custom code ###
+    # Premade documentation that can be used when not using custom code #
     @property
     def Premade_documentation_data(self):
         """
@@ -92,7 +130,7 @@ class Settings:
         """
         :type: string
         """
-        self._premade_documentation_data = value
+        self._premade_documentation_data = GF.Is_value_string(value=value)
 
     @property
     def Enviroment_name(self):
@@ -106,7 +144,21 @@ class Settings:
         """
         :type: string
         """
-        self._enviroment_name = value
+        self._enviroment_name = GF.Is_value_string(value=value)
+
+    @property
+    def Enviroment_version(self):
+        """
+        :type: string
+        """
+        return self._enviroment_version
+
+    @Enviroment_version.setter
+    def Enviroment_version(self, value):
+        """
+        :type: string
+        """
+        self._enviroment_version = GF.Is_value_string(value=value)
 
     @property
     def Package_version(self):
@@ -120,7 +172,7 @@ class Settings:
         """
         :type: string
         """
-        self._package_version = value
+        self._package_version = GF.Is_value_string(value=value)
 
     @property
     def Base_url(self):
@@ -134,7 +186,7 @@ class Settings:
         """
         :type: string
         """
-        self._base_url = value
+        self._base_url = GF.Is_value_string(value=value)
 
     @property
     def Username(self):
@@ -148,7 +200,7 @@ class Settings:
         """
         :type: string
         """
-        self._username = value
+        self._username = GF.Is_value_string(value=value)
 
     @property
     def Token(self):
@@ -162,7 +214,7 @@ class Settings:
         """
         :type: string
         """
-        self._token = value
+        self._token = GF.Is_value_string(value=value)
 
     @property
     def Platform_version(self):
@@ -176,4 +228,18 @@ class Settings:
         """
         :type: string
         """
-        self._platform_version = value[0:3]
+        self._platform_version = value[0:4]
+
+    @property
+    def Gitaccesstoken(self):
+        """
+        :type: string
+        """
+        return self._gitaccesstoken
+
+    @Gitaccesstoken.setter
+    def Gitaccesstoken(self, value):
+        """
+        :type: string
+        """
+        self._gitaccesstoken = GF.Is_value_string(value=value)
